@@ -246,8 +246,9 @@ static void dockimlib2_setup_imlib(DockImlib2 *dock) {
   /* some default font paths */
   snprintf(fp, 512, "%s/.fonts", getenv("HOME"));
   add_fontpath(fp,1);
-  add_fontpath("/usr/share/fonts/truetype",1);
-  add_fontpath("/usr/share/fonts/ttf",1);
+  /*add_fontpath("/usr/share/fonts/truetype",1);
+  add_fontpath("/usr/share/fonts/ttf",1);*/
+  add_fontpath("/usr/share/fonts",1);
   add_fontpath("/usr/X11R6/lib/X11/fonts/truetype",1);
   add_fontpath("/usr/X11R6/lib/X11/fonts/TrueType",1);
   add_fontpath("/usr/X11R6/lib/X11/fonts/ttf",1);
