@@ -223,6 +223,14 @@ void draw_swap_matrix(App *app) {
   }
 }
 
+float f2celsius(float Tf) {
+  return (5./9.)*(Tf-32.);
+}
+
+float celsius2f(float Tc) {
+  return (9./5.)*Tc+32.;
+}
+
 static void query_hddtemp(App *app) {
   int fd;
   struct hostent *h;
@@ -267,10 +275,24 @@ static void query_hddtemp(App *app) {
         if (found) {
           s=strchr(s,'|');
           if (s && ((s=strchr(s+1,'|')))) {
-            char *p = strchr(++s,'|'), oldv=0; if (p) { oldv = *p; *p = 0; }
-            BLAHBLAH(1,printf("temperature of '%s' : %s\n", dl->name, s));
+	    int unit = 'C';
+            char *p = strchr(++s,'|'), oldv=0; 
+	    if (p) { 
+	      oldv = *p; 
+	      if (*p && toupper(p[1]) == 'F') unit = 'F';
+	      *p = 0; 
+	    }
+            BLAHBLAH(1,printf("temperature of '%s' : %s %c\n", dl->name, s, unit));
             if (strcmp(s,"SLP") == 0) app->disk_temperature[cnt] = -2;
-            else app->disk_temperature[cnt] = atoi(s);
+            else {
+	      int temp = atoi(s);
+	      if (unit == 'C' && Prefs.temperatures_unit == 'F') {
+		temp = (int)(floor(celsius2f(temp)+.5));
+	      } else if (unit == 'F' && Prefs.temperatures_unit == 'C') {
+		temp = (int)(floor(f2celsius(temp)+.5));
+	      }
+	      app->disk_temperature[cnt] = temp;
+	    }
             if (p) *p = oldv; /* or bug... */
           }
         } else {
@@ -441,11 +463,42 @@ static void draw_hdlist(App *app) {
         strcpy(s,"SLP");
       }
       imlib_get_text_size(s,&w,&h);
-      x = lx + lw - w + ((app->disk_temperature[hd_cnt] != -2) ? -6 : -2);
+      x = lx + lw - w + ((app->disk_temperature[hd_cnt] != -2) ? -7 : -3);
       imlib_context_set_color(255, 250, 100, 255);
       my_imlib_text_draw(x, y-h, s);
       imlib_context_set_color(255, 255, 255, 200);
-      if (app->disk_temperature[hd_cnt] != -2) imlib_image_draw_ellipse(x+w+3, y - h + 2, 1, 1);
+
+      /* below is a quick fix for the degree sign which is not drawn
+	 properly by recent release of imlib -- many thanks to
+	 Krzysztof Kotlenga for the patch */
+
+      //if (app->disk_temperature[hd_cnt] != -2) imlib_image_draw_ellipse(x+w+3, y - h + 2, 1, 1);
+
+      //if (app->disk_temperature[hd_cnt] != -2) imlib_image_draw_ellipse(x+w+3, y - h + 2, 1, 1);
+      /* imlib2 >= 1.1.1 workaround - imlib_image_draw_ellipse() can't properly draw circle with radius = 1 */
+      if (app->disk_temperature[hd_cnt] != -2) {
+        /*ImlibPolygon poly;
+        poly = imlib_polygon_new();
+        imlib_polygon_add_point(poly, x+w+3, y-h+3);
+        imlib_polygon_add_point(poly, x+w+2, y-h+2);
+        imlib_polygon_add_point(poly, x+w+3, y-h+1);
+        imlib_polygon_add_point(poly, x+w+4, y-h+2);
+        imlib_image_draw_polygon(poly, 1);*/
+	/*imlib_image_draw_pixel(x+w+3, y-h+3, 0);
+	imlib_image_draw_pixel(x+w+2, y-h+2, 0);
+	imlib_image_draw_pixel(x+w+3, y-h+1, 0);
+	imlib_image_draw_pixel(x+w+4, y-h+2, 0);*/
+
+	int i=x+w+2, j=y-h;
+	imlib_image_draw_pixel(i+1,j,0);
+	imlib_image_draw_pixel(i+2,j,0);
+	imlib_image_draw_pixel(i+3,j+1,0);
+	imlib_image_draw_pixel(i+3,j+2,0);
+	imlib_image_draw_pixel(i+1,j+3,0);
+	imlib_image_draw_pixel(i+2,j+3,0);
+	imlib_image_draw_pixel(i,j+1,0);
+	imlib_image_draw_pixel(i,j+2,0);
+      }
     }
   }
 }
@@ -721,6 +774,7 @@ void init_prefs(int argc, char **argv) {
   Prefs.popup_throughput_pos = AL_TOP;
   Prefs.xprefs.argc = argc; Prefs.xprefs.argv = argv;
   Prefs.xprefs.flags = 0;
+  Prefs.temperatures_unit = 'C';
 }
 
 #ifndef GKRELLM
@@ -733,6 +787,7 @@ void parse_options(int argc, char **argv) {
     {"verbose",0,0,'v'},
     {"version",0,0,'V'},
     {"hddtemp",0,0,'t'},
+    {"farenheit",0,0,'F'},
     {"display",1,0,OPT_DISPLAY},
     {"geometry",2,0,'g'},
     {"smallfont",1,0,OPT_SMALLFONT},
@@ -759,7 +814,8 @@ void parse_options(int argc, char **argv) {
     "  -v, --verbose   increase verbosity\n"
     "  -V, --version   print version\n"
     "  -t[=port], --hddtemp[=port]\n"
-    "                  display hd temperatures (requires hddtemp daemon running)\n"
+    "                  display hd temperatures, in Celsius degrees (requires hddtemp daemon running)\n"
+    "  -F, --farenheit display hd temperatures in Farenheit degrees\n"
     /*    "  -p : monitor harddrive power status (idle, standby or sleeping, as reported by hdparm -C)\n"
           "       note that this options requires that wmhd is suid..\n"*/ /* hddtemp already reports when a drive is asleep ... */
     "  --noswap        disable the animation reflecting swap activity\n"
@@ -797,7 +853,7 @@ void parse_options(int argc, char **argv) {
   init_prefs(argc, argv);
   while (1) {
     int c;
-    c = getopt_long(argc, argv, "g::hvVt::c:LP:d:@:",long_options,&long_options_index); /* -g option is handled in dockapp_imlib2 */
+    c = getopt_long(argc, argv, "g::hvVt::Fc:LP:d:@:",long_options,&long_options_index); /* -g option is handled in dockapp_imlib2 */
     if (c == -1)
       break;
     switch (c) {
@@ -825,6 +881,10 @@ void parse_options(int argc, char **argv) {
         /*case 'p':
           Prefs.enable_power_status = 1;
           break;*/
+      case 'F':
+        Prefs.enable_hddtemp = 1;
+	Prefs.temperatures_unit = 'F';
+	break;
       case OPT_NOIO:
         Prefs.disable_io_matrix = 1;
         break;
@@ -895,8 +955,8 @@ char *xstrdup(const char *s) {
 }
 
 void init_fonts(App *app) {
-  char *bigfontlist[] = {"Arial_Black/10", "FreeSansBold/11", "VeraMoBd/9", "arialbd/12", "Vera/9", "Verdana_Bold/10", "VerdanaBd/10", "Verdana/10", NULL};
-  char *smallfontlist[] = {"Vera/7","FreeSans/7","Trebuchet_MS/7","Verdana/7","Arial/7", NULL};
+  char *bigfontlist[] = {"Arial_Black/10", "luxisb/11", "VeraMoBd/9", "arialbd/12", "Vera/9", "Verdana_Bold/10", "VerdanaBd/10", "Verdana/10", "FreeSansBold/11", NULL};
+  char *smallfontlist[] = {"Vera/7","Trebuchet_MS/7", "luxisr/7", "Verdana/7","Arial/7","FreeSans/7", NULL};
   if (app->bigfont) {
     imlib_context_set_font(app->bigfont); imlib_free_font(); app->bigfont = NULL;
   }
